authj
authj is an authorization middleware for net/http, it's based on
casbin.

Installation
go get github.com/thinkgos/http-middlewares/authj
Simple Example
package main
import (
"net/http"
"github.com/casbin/casbin/v2"
"github.com/thinkgos/http-middlewares/authj"
)
func main() {
// load the casbin model and policy from files, database is also supported.
e ,err := casbin.NewEnforcer("authz_model.conf", "authz_policy.csv")
if err!= nil{
panic(err)
}
// define your router, and use the Casbin authj middleware.
// the access that is denied by authz will return HTTP 403 error.
// before you use middleware2 your should use middleware1 to set subject
middleware1 := func(next http.HandlerFunc) http.HandlerFunc{
return func(w http.ResponseWriter, r *http.Request) {
next.ServeHTTP(w, r.WithContext(authj.ContextWithSubject(r.Context(), "admin")))
}
}
middleware2 := authj.NewAuthorizer(e)
}
Documentation
The authorization determines a request based on {subject, object, action}, which means what subject can perform what action on what object. In this plugin, the meanings are:
subject: the logged-on user name
object: the URL path for the web resource like "dataset1/item1"
action: HTTP method like GET, POST, PUT, DELETE, or the high-level actions you defined like "read-file", "write-blog"
For how to write authorization policy and other details, please refer to the Casbin's documentation.
Getting Help
License
This project is under MIT License. See the LICENSE file for the full license text.